"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emit = void 0;
const MethodParameterTokens = require("../tokens/method_parameter_tokens");
const ModifierTokens = require("../tokens/modifier_tokens");
const InvokeConstructorTokens = require("../tokens/invoke_constructor_tokens");
const ScopeEmitter = require("./scope_emitter");
function emit(writer, typeName, constructor) {
    emitDefinition(writer, typeName, constructor);
    emitBody(writer, constructor);
}
exports.emit = emit;
function emitDefinition(writer, typeName, constructor) {
    const { access, isStatic, parameters, invokeConstructor } = constructor;
    writer
        .outputTabs()
        .write(...ModifierTokens.forAccess(access))
        .write(...ModifierTokens.forStatic(isStatic))
        .write(typeName)
        .write(...MethodParameterTokens.emit(parameters))
        .write(...InvokeConstructorTokens.emit(invokeConstructor))
        .writeLineNoTabs();
}
function emitBody(writer, constructor) {
    const { body } = constructor;
    ScopeEmitter.emit(writer, writer => body.statements.forEach(s => writer.writeLine(s)));
}
